#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://goodies.xfce.org/projects/applications/parole
# source location    : http://archive.xfce.org/src/apps/parole/0.2/parole-0.2.0.2.tar.bz2
# last revised       : 15.1.2010
# dep                : 

softname='parole'
softversion='0.2.0.2'
packageversion='64.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://archive.xfce.org/src/apps/parole/0.2/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
      |-----handy-ruler------------------------------------------------------|
parole: parole - a modern simple media player based on the GStreamer 
parole: 
parole: Parole features playback of local media files, DVD/CD and live 
parole: streams.Parole is extensible via plugins, for a complete how to 
parole: write a plugin for Parole see the Plugins API documentation+the 
parole: plugins directory which contains some usefull examples.
parole: 
parole: 
parole: 
parole:
parole: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-gtk-doc \
	--enable-taglib \
	--enable-libnotify \
	--enable-browser \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

# add 'default' files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   INSTALL README COPYING AUTHORS NEWS THANKS TODO ChangeLog\
   $dest/usr/doc/$softname-$softversion
        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,cxxlibs|gcc-g++,dbus,dbus-glib,e2fsprogs,\
expat,fontconfig,freetype,gcc,glib2,glitz,gst-plugins-base,gstreamer,\
gtk+2,libICE,libSM,libX11,libXau,libXcomposite,libXcursor,libXdamage,\
libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,\
libnotify,libpng,libxcb,libxml2,pango,pixman,startup-notification,\
taglib,xcb-util,xfce-base,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/parole/source/build-parole.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
